![pyneb logo](https://pyneb.dev/assets/img/pyneb.png)

# The Python Nudged Elastic Band Package 

PyNEB provides a highly extensible and general purpose action minimization package for generic potential energy surfaces.
